@@ -1,6 +1,7 @@
 OC.L10N.register(
     "spreed",
     {
+    "a conversation" : "대화",
     "(Duration %s)" : "(시간 %s)",
     "You attended a call with {user1}" : "{user1} 님과의 통화에 참가함",
     "_%n guest_::_%n guests_" : ["손님 %n명"],
@@ -10,14 +11,20 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "{user1}, {user2}, {user3}, {user4}, {user5} 님과의 통화에 참가함",
     "_%n other_::_%n others_" : ["외 %n명"],
     "{actor} invited you to {call}" : "{actor} 님이 {call}에 초대함",
+    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "당신은 <strong>대화</strong>에 초대되었거나 <strong>통화</strong>를 했습니다",
     "Talk" : "토크",
     "Guest" : "손님",
+    "- Spice up your messages with emojis from the emoji picker" : "- 이모티콘 선택을 통해 이모티콘을 사용하여 대화를 꾸며보세요",
+    "- Spice up your messages with emojis from the emoji picker {emoji}" : "- 이모티콘 선택을 통해 이모티콘을 사용하여 대화를 꾸며보세요 {emoji}",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "환영합니다!\n이것으로 Nextcloud Talk에서 가능한 것들을 알게될 것입니다.",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "마이크로소프트 에지와 사파리는 음성 통화와 영상 통화에 참여하는데 사용될 수 있습니다.",
     "There are currently no commands available." : "현재 가능한 명령이 없습니다.",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "명령을 수행하던 중 에러가 발생했습니다. 기록을 확인하려면 관리자에게 문의하십시오.",
+    "Talk updates ✅" : "토크 업데이트 ✅",
     "{actor} created the conversation" : "{actor}가 대화를 생성했습니다.",
+    "{actor} started a call" : "{actor}님이 통화 시작",
     "You started a call" : "통화를 시작했습니다.",
+    "{actor} joined the call" : "{actor}님이 통화에 참여",
     "You joined the conversation" : "대화에 참여하였습니다.",
     "Talk to %s" : "%s 님과 대화",
     "Join call" : "통화 참가하기",
@@ -70,6 +77,7 @@ OC.L10N.register(
     "Expired" : "만료됨",
     "Shared secret" : "공유된 비밀 값",
     "Validate SSL certificate" : "SSL 인증서 확인",
+    "Delete this server" : "이 서버 삭제",
     "Saved" : "저장됨",
     "STUN servers" : "STUN 서버",
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUN 서버는 라우터 뒤에 있는 참가자의 공인 IP 주소를 판단하는 데 사용합니다.",
@@ -84,7 +92,10 @@ OC.L10N.register(
     "Show your screen" : "내 화면 보이기",
     "Stop screensharing" : "화면 공유 중지",
     "Dismiss" : "무시",
+    "No audio" : "오디오 없음",
+    "Mute audio (m)" : "오디오 음소거 (m)",
     "Mute audio" : "오디오 음소거",
+    "Disable video (v)" : "비디오 비활성화 (v)",
     "Disable video" : "비디오 비활성화",
     "Enable video" : "비디오 활성화",
     "Screensharing options" : "화면 공유 옵션",
@@ -94,11 +105,14 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "화면 공유를 위한 확장 기능이 필요합니다.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "화면 공유를 사용하려면 Firefox 및 Chrome과 같은 다른 웹 브라우저를 사용하십시오.",
     "An error occurred while starting screensharing." : "화면 공유를 시작하는 중 오류가 발생했습니다.",
+    "Back" : "뒤로",
     "You" : "나",
     "Show screen" : "화면 보이기",
     "Drop your files to upload" : "업로드를 하려면 파일을 올리시오.",
     "Favorite" : "즐겨찾기",
     "Conversation settings" : "대화 환경설정",
+    "Password protection" : "암호 보호",
+    "Enter a password" : "Enter a password",
     "Leave conversation" : "대화 나가기",
     "Delete conversation" : "대화 삭제",
     "Remove from favorites" : "즐겨찾기에서 제거",
@@ -108,7 +122,6 @@ OC.L10N.register(
     "Circles" : "서클",
     "Settings" : "설정",
     "Password protect" : "암호 보호",
-    "Back" : "뒤로",
     "Close" : "닫기",
     "Conversation name" : "대화명",
     "Camera" : "카메라",
@@ -134,14 +147,14 @@ OC.L10N.register(
     "No results" : "결과 없음",
     "Add users or groups" : "사용자나 그룹 추가",
     "Participants" : "참가자",
+    "Search or add participants" : "참가자 검색 및 추가",
     "Chat" : "대화",
     "Edit" : "편집",
     "Keyboard shortcuts" : "키보드 단축키",
     "Search" : "검색",
+    "Start call" : "통화 시작",
     "Rename conversation" : "대화 제목 변경",
-    "Share link" : "링크 공유",
-    "Password protection" : "암호 보호",
-    "Enter a password" : "Enter a password",
+    "Exit fullscreen (f)" : "전체화면 끝내기 (f)",
     "Grid view" : "바둑판식 보기",
     "Send" : "보내기",
     "Start a conversation" : "대화 시작",
@@ -164,6 +177,7 @@ OC.L10N.register(
     "[Unknown user name]" : "[알 수 없는 사용자 이름]",
     "Add contacts" : "연락처 추가",
     "Guests" : "손님",
+    "Share link" : "링크 공유",
     "Projects" : "프로젝트",
     "Please enter the password for this call" : "이 통화의 암호를 입력하십시오",
     "Password required" : "암호가 필요함",
