@@ -30,6 +30,7 @@ OC.L10N.register(
     "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Dabar, pokalbių ir dalyvių paieška taip pat filtruos ir jūsų esamus pokalbius, todėl bus žymiai lengviau rasti ankstesnius pokalbius",
     "- You can now add custom user groups to conversations when the circles app is installed" : "- Nuo šiol, kai turite įdiegtą ratų programėlę, galite pridėti į pokalbius tinkintas naudotojų grupes",
     "New in Talk 9" : "Nauja Pokalbiuose 9",
+    "New in Talk 10" : "Nauja Pokalbiuose 10",
     "There are currently no commands available." : "Šiuo metu nėra prieinamų komandų.",
     "The command does not exist" : "Komandos nėra",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Vykdant komandą, įvyko klaida. Paprašykite administratoriaus, kad patikrintų žurnalus.",
@@ -82,6 +83,8 @@ OC.L10N.register(
     "{actor} promoted {user} to moderator" : "{actor} paaukštino naudotoją {user} į moderatorius",
     "You promoted {user} to moderator" : "Jūs paaukštinote naudotoją {user} į moderatorius",
     "{actor} promoted you to moderator" : "{actor} paaukštino jus į moderatorius",
+    "An administrator promoted you to moderator" : "Administratorius paaukštino jus į moderatorius",
+    "An administrator promoted {user} to moderator" : "Administratorius paaukštino naudotoją {user} į moderatorius",
     "{actor} demoted {user} from moderator" : "{actor} pažemino naudotoją {user} iš moderatorių",
     "You demoted {user} from moderator" : "Jūs pažeminote naudotoją {user} iš moderatorių",
     "{actor} demoted you from moderator" : "{actor} pažemino jus iš moderatorių",
@@ -111,6 +114,8 @@ OC.L10N.register(
     "Conversation invitation" : "Pakvietimas į pokalbį",
     "Click the button below to join." : "Norėdami prisijungti, spustelėkite mygtuką žemiau.",
     "Join »%s«" : "Prisijungti prie »%s«",
+    "Meeting ID" : "Susitikimo ID",
+    "Your PIN" : "Jūsų PIN kodas",
     "Password request: %s" : "Slaptažodžio prašymas: %s",
     "Private conversation" : "Privatus pokalbis",
     "Deleted user (%s)" : "Ištrintas naudotojas (%s)",
@@ -134,6 +139,7 @@ OC.L10N.register(
     "Join call" : "Prisijungti prie skambučio",
     "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
     "Answer call" : "Atsiliepti",
+    "{user} would like to talk with you" : "{user} norėtų su jumis pakalbėti",
     "Call back" : "Atskambinti",
     "You missed a call from {user}" : "Jūs praleidote skambutį nuo {user}",
     "A group call has started in {call}" : "Grupės skambutis prasidėjo ties {call}",
@@ -148,6 +154,7 @@ OC.L10N.register(
     "{user}" : "{user}",
     "Something unexpected happened." : "Nutiko kažkas netikėto.",
     "The URL is invalid." : "URL yra neteisingas.",
+    "An HTTPS URL is required." : "Reikalingas HTTPS URL.",
     "The email address is invalid." : "El. pašto adresas yra neteisingas.",
     "The language is invalid." : "Neteisinga kalba.",
     "The country is invalid." : "Neteisinga šalis.",
@@ -449,6 +456,7 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
     "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
+    "Back" : "Atgal",
     "Access to camera was denied" : "Prieiga prie kameros buvo uždrausta",
     "Error while accessing camera" : "Klaida gaunant prieigą prie kameros",
     "You" : "Jūs",
@@ -456,6 +464,10 @@ OC.L10N.register(
     "Mute" : "Nutildyti",
     "Favorite" : "Mėgstamas",
     "Conversation settings" : "Pokalbio nustatymai",
+    "Password protection" : "Apsauga slaptažodžiu",
+    "Enter a password" : "Enter a password",
+    "Enable lobby" : "Įjungti laukimo salę",
+    "Start time (optional)" : "Pradžios laikas (nebūtinas)",
     "Chat notifications" : "Pokalbio pranešimai",
     "Leave conversation" : "Išeiti iš pokalbio",
     "Delete conversation" : "Ištrinti pokalbį",
@@ -483,7 +495,6 @@ OC.L10N.register(
     "Create a new group conversation" : "Sukurti naują grupės pokalbį",
     "Password protect" : "Apsaugoti slaptažodžiu",
     "Add participants" : "Pridėti dalyvius",
-    "Back" : "Atgal",
     "Create conversation" : "Sukurti pokalbį",
     "Close" : "Užverti",
     "Search participants" : "Ieškoti dalyvių",
@@ -542,7 +553,6 @@ OC.L10N.register(
     "unknown state" : "nežinoma būsena",
     "moderator" : "moderatorius",
     "guest" : "svečias",
-    "Participant settings" : "Dalyvio nustatymai",
     "Demote from moderator" : "Pažeminti iš moderatorių",
     "Promote to moderator" : "Paaukštinti į moderatorius",
     "Remove participant" : "Šalinti dalyvį",
@@ -569,11 +579,6 @@ OC.L10N.register(
     "Toggle fullscreen" : "Perjungti visą ekraną",
     "Go to file" : "Pereiti į failą",
     "Rename conversation" : "Pervadinti pokalbį",
-    "Share link" : "Bendrinimo nuoroda",
-    "Password protection" : "Apsauga slaptažodžiu",
-    "Enter a password" : "Enter a password",
-    "Enable lobby" : "Įjungti laukimo salę",
-    "Start time (optional)" : "Pradžios laikas (nebūtinas)",
     "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
     "Fullscreen (f)" : "Visas ekranas (f)",
     "Grid view" : "Tinklelio rodinys",
@@ -628,6 +633,7 @@ OC.L10N.register(
     "Loading contacts" : "Įkeliami adresatai",
     "Search conversations or contacts" : "Ieškoti pokalbių ar adresatų",
     "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
+    "Participant settings" : "Dalyvio nustatymai",
     "Search for more contacts" : "Ieškoti daugiau adresatų",
     "Contacts loading" : "Įkeliami adresatai",
     "Add participants to the conversation" : "Pridėti dalyvius į pokalbį",
@@ -636,6 +642,7 @@ OC.L10N.register(
     "Add contacts or groups" : "Pridėti adresatus ar grupes",
     "Add contacts or circles" : "Pridėti adresatus ar ratus",
     "Guests" : "Svečiai",
+    "Share link" : "Bendrinimo nuoroda",
     "Webinar" : "Internetinis seminaras",
     "Projects" : "Projektai",
     "Start calls" : "Pradeda skambučius",
