@@ -26,6 +26,7 @@ namespace OCA\Talk\Chat\Parser;
 
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\GuestManager;
+use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Message;
 use OCA\Talk\Room;
 use OCP\Comments\ICommentsManager;
@@ -109,10 +110,15 @@ class UserMention {
 			$message = str_replace($placeholder, '{' . $mentionParameterId . '}', $message);
 
 			if ($mention['type'] === 'call') {
+				$userId = '';
+				if ($chatMessage->getParticipant()->getAttendee()->getActorType() === Attendee::ACTOR_USERS) {
+					$userId = $chatMessage->getParticipant()->getAttendee()->getActorId();
+				}
+
 				$messageParameters[$mentionParameterId] = [
 					'type' => $mention['type'],
 					'id' => $chatMessage->getRoom()->getToken(),
-					'name' => $chatMessage->getRoom()->getDisplayName($chatMessage->getParticipant()->getUser()),
+					'name' => $chatMessage->getRoom()->getDisplayName($userId),
 					'call-type' => $this->getRoomType($chatMessage->getRoom()),
 				];
 			} elseif ($mention['type'] === 'guest') {
