@@ -86,7 +86,7 @@ class ConversationProvider implements IProvider {
 		}
 
 		try {
-			$room = $this->manager->getRoomForParticipantByToken(
+			$room = $this->manager->getRoomForUserByToken(
 				$resource->getId(),
 				$userId
 			);
@@ -94,7 +94,7 @@ class ConversationProvider implements IProvider {
 			// Logged in users need to have a regular participant,
 			// before they can do anything with the room.
 			$participant = $room->getParticipant($userId);
-			return $participant->getParticipantType() !== Participant::USER_SELF_JOINED;
+			return $participant->getAttendee()->getParticipantType() !== Participant::USER_SELF_JOINED;
 		} catch (RoomNotFoundException $e) {
 			throw new ResourceException('Conversation not found');
 		} catch (ParticipantNotFoundException $e) {
