@@ -74,7 +74,7 @@ class Update extends Base {
 			);
 	}
 
-	protected function execute(InputInterface $input, OutputInterface $output): ?int {
+	protected function execute(InputInterface $input, OutputInterface $output): int {
 		$token = $input->getArgument('token');
 		$name = $input->getOption('name');
 		$public = $input->getOption('public');
