@@ -26,8 +26,11 @@ declare(strict_types=1);
 namespace OCA\Talk\Signaling;
 
 use OCA\Talk\Config;
+use OCA\Talk\Model\Attendee;
+use OCA\Talk\Model\Session;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
+use OCA\Talk\Service\ParticipantService;
 use OCP\Http\Client\IClientService;
 use OCP\IURLGenerator;
 use OCP\Security\ISecureRandom;
@@ -44,6 +47,8 @@ class BackendNotifier {
 	private $secureRandom;
 	/** @var Manager */
 	private $signalingManager;
+	/** @var ParticipantService */
+	private $participantService;
 	/** @var IUrlGenerator */
 	private $urlGenerator;
 
@@ -52,12 +57,14 @@ class BackendNotifier {
 								IClientService $clientService,
 								ISecureRandom $secureRandom,
 								Manager $signalingManager,
+								ParticipantService $participantService,
 								IURLGenerator $urlGenerator) {
 		$this->config = $config;
 		$this->logger = $logger;
 		$this->clientService = $clientService;
 		$this->secureRandom = $secureRandom;
 		$this->signalingManager = $signalingManager;
+		$this->participantService = $participantService;
 		$this->urlGenerator = $urlGenerator;
 	}
 
@@ -141,7 +148,9 @@ class BackendNotifier {
 		$this->logger->info('Now invited to ' . $room->getToken() . ': ' . print_r($users, true));
 		$userIds = [];
 		foreach ($users as $user) {
-			$userIds[] = $user['userId'];
+			if ($user['actorType'] === Attendee::ACTOR_USERS) {
+				$userIds[] = $user['actorId'];
+			}
 		}
 		$this->backendRequest($room, [
 			'type' => 'invite',
@@ -149,7 +158,7 @@ class BackendNotifier {
 				'userids' => $userIds,
 				// TODO(fancycode): We should try to get rid of 'alluserids' and
 				// find a better way to notify existing users to update the room.
-				'alluserids' => $room->getParticipantUserIds(),
+				'alluserids' => $this->participantService->getParticipantUserIds($room),
 				'properties' => $room->getPropertiesForSignaling(''),
 			],
 		]);
@@ -170,7 +179,7 @@ class BackendNotifier {
 				'userids' => $userIds,
 				// TODO(fancycode): We should try to get rid of 'alluserids' and
 				// find a better way to notify existing users to update the room.
-				'alluserids' => $room->getParticipantUserIds(),
+				'alluserids' => $this->participantService->getParticipantUserIds($room),
 				'properties' => $room->getPropertiesForSignaling(''),
 			],
 		]);
@@ -191,7 +200,7 @@ class BackendNotifier {
 				'sessionids' => $sessionIds,
 				// TODO(fancycode): We should try to get rid of 'alluserids' and
 				// find a better way to notify existing users to update the room.
-				'alluserids' => $room->getParticipantUserIds(),
+				'alluserids' => $this->participantService->getParticipantUserIds($room),
 				'properties' => $room->getPropertiesForSignaling(''),
 			],
 		]);
@@ -208,7 +217,7 @@ class BackendNotifier {
 		$this->backendRequest($room, [
 			'type' => 'update',
 			'update' => [
-				'userids' => $room->getParticipantUserIds(),
+				'userids' => $this->participantService->getParticipantUserIds($room),
 				'properties' => $room->getPropertiesForSignaling(''),
 			],
 		]);
@@ -218,12 +227,11 @@ class BackendNotifier {
 	 * The given room has been deleted.
 	 *
 	 * @param Room $room
-	 * @param array $participants
+	 * @param string[] $userIds
 	 * @throws \Exception
 	 */
-	public function roomDeleted(Room $room, array $participants): void {
+	public function roomDeleted(Room $room, array $userIds): void {
 		$this->logger->info('Room deleted: ' . $room->getToken());
-		$userIds = array_keys($participants['users']);
 		$this->backendRequest($room, [
 			'type' => 'delete',
 			'delete' => [
@@ -243,29 +251,44 @@ class BackendNotifier {
 		$this->logger->info('Room participants modified: ' . $room->getToken() . ' ' . print_r($sessionIds, true));
 		$changed = [];
 		$users = [];
-		$participants = $room->getParticipantsLegacy();
-		foreach ($participants['users'] as $userId => $participant) {
-			$participant['userId'] = $userId;
-			$users[] = $participant;
-			if (\in_array($participant['sessionId'], $sessionIds, true)) {
-				$participant['permissions'] = ['publish-media', 'publish-screen'];
-				if ($participant['participantType'] === Participant::OWNER ||
-						$participant['participantType'] === Participant::MODERATOR) {
-					$participant['permissions'][] = 'control';
+		$participants = $this->participantService->getParticipantsForRoom($room);
+		foreach ($participants as $participant) {
+			$attendee = $participant->getAttendee();
+			if ($attendee->getActorType() !== Attendee::ACTOR_USERS
+				&& $attendee->getActorType() !== Attendee::ACTOR_GUESTS) {
+				continue;
+			}
+
+			$data = [
+				'inCall' => Participant::FLAG_DISCONNECTED,
+				'lastPing' => 0,
+				'sessionId' => '0',
+				'participantType' => $attendee->getParticipantType(),
+			];
+			if ($attendee->getActorType() === Attendee::ACTOR_USERS) {
+				$data['userId'] = $attendee->getActorId();
+			}
+
+			$session = $participant->getSession();
+			if ($session instanceof Session) {
+				$data['inCall'] = $session->getInCall();
+				$data['lastPing'] = $session->getLastPing();
+				$data['sessionId'] = $session->getSessionId();
+				$users[] = $data;
+
+				if (\in_array($session->getSessionId(), $sessionIds, true)) {
+					$data['permissions'] = ['publish-media', 'publish-screen'];
+					if ($attendee->getParticipantType() === Participant::OWNER ||
+						$attendee->getParticipantType() === Participant::MODERATOR) {
+						$data['permissions'][] = 'control';
+					}
+					$changed[] = $data;
 				}
-				$changed[] = $participant;
-			}
-		}
-		foreach ($participants['guests'] as $participant) {
-			if (!isset($participant['participantType'])) {
-				$participant['participantType'] = Participant::GUEST;
-			}
-			$users[] = $participant;
-			if (\in_array($participant['sessionId'], $sessionIds, true)) {
-				$participant['permissions'] = ['publish-media', 'publish-screen'];
-				$changed[] = $participant;
+			} else {
+				$users[] = $data;
 			}
 		}
+
 		$this->backendRequest($room, [
 			'type' => 'participants',
 			'participants' => [
@@ -287,25 +310,38 @@ class BackendNotifier {
 		$this->logger->info('Room in-call status changed: ' . $room->getToken() . ' ' . $flags . ' ' . print_r($sessionIds, true));
 		$changed = [];
 		$users = [];
-		$participants = $room->getParticipantsLegacy();
-		foreach ($participants['users'] as $userId => $participant) {
-			$participant['userId'] = $userId;
-			if ($participant['inCall'] !== Participant::FLAG_DISCONNECTED) {
-				$users[] = $participant;
+
+		$participants = $this->participantService->getParticipantsForRoom($room);
+		foreach ($participants as $participant) {
+			$attendee = $participant->getAttendee();
+			if ($attendee->getActorType() !== Attendee::ACTOR_USERS
+				&& $attendee->getActorType() !== Attendee::ACTOR_GUESTS) {
+				continue;
 			}
-			if (\in_array($participant['sessionId'], $sessionIds, true)) {
-				$changed[] = $participant;
+
+			$data = [
+				'inCall' => Participant::FLAG_DISCONNECTED,
+				'lastPing' => 0,
+				'sessionId' => '0',
+				'participantType' => $attendee->getParticipantType(),
+			];
+			if ($attendee->getActorType() === Attendee::ACTOR_USERS) {
+				$data['userId'] = $attendee->getActorId();
 			}
-		}
-		foreach ($participants['guests'] as $participant) {
-			if (!isset($participant['participantType'])) {
-				$participant['participantType'] = Participant::GUEST;
-			}
-			if ($participant['inCall'] !== Participant::FLAG_DISCONNECTED) {
-				$users[] = $participant;
-			}
-			if (\in_array($participant['sessionId'], $sessionIds, true)) {
-				$changed[] = $participant;
+
+			$session = $participant->getSession();
+			if ($session instanceof Session) {
+				$data['inCall'] = $session->getInCall();
+				$data['lastPing'] = $session->getLastPing();
+				$data['sessionId'] = $session->getSessionId();
+
+				if ($session->getInCall() !== Participant::FLAG_DISCONNECTED) {
+					$users[] = $data;
+				}
+
+				if (\in_array($session->getSessionId(), $sessionIds, true)) {
+					$changed[] = $data;
+				}
 			}
 		}
 
